<?php

namespace EventPortal\Domain\Event\Models;

use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Speaker\Models\Speaker;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\Pivot;

class EventSpeaker extends Pivot
{
    public const KEY = 'eventSpeaker';

    /** @var string */
    protected $table = 'event_speaker';

    /** @var array<string> */
    public $with = [
        'speaker',
        'event',
    ];

    public $incrementing = true;

    public function event(): BelongsTo
    {
        return $this->belongsTo(Event::class);
    }

    public function speaker(): BelongsTo
    {
        return $this->belongsTo(Speaker::class);
    }

    public function sessions(): BelongsToMany
    {
        return $this->belongsToMany(
            Session::class,
            'event_speaker_session',
            'event_speaker_id',
            'session_id'
        );
    }

    public function scopeForEventAndSpeaker(Builder $query, Event $event, Speaker $speaker): Builder
    {
        return $query
            ->where('event_id', $event->id)
            ->where('speaker_id', $speaker->id);
    }

    public function scopeForEvent(Builder $query, Event $event): Builder
    {
        return $query->where('event_id', $event->id);
    }

    public function scopeForSession(Builder $query, Session $session): Builder
    {
        return $query->whereHas('sessions', function (Builder $query) use ($session) {
            return $query->where('session_id', '=', $session->id);
        });
    }

    public function asOption(): Option
    {
        return Option::make($this->speaker->name)->value($this->id);
    }
}
